class PackagesController < ApplicationController
  # GET /packages
  # GET /packages.xml
  def index
    # check parameters to filter out what we display
    if params[:only]
      case params[:only]
        when "maintained" then @packages = Package.maintained
        when "unmaintained" then @packages = Package.unmaintained
        when "orphans" then @packages = Package.unmaintained
        else @packages = []
      end
    elsif params[:by]
        @maintainer = Maintainer.find_by_uid(params[:by])
        @packages = @maintainer.packages
    else
      @packages = Package.all
    end
    # TODO limit/pagination, see http://mageia.org/wiki/doku.php?id=web:maintdb#list_packages

    respond_to do |format|
      format.html # index.html.erb
      format.xml  { render :xml => @packages }
      format.json { render :json => @packages }
    end
  end

  # GET /packages/1
  # GET /packages/1.xml
  def show
    @package = Package.find(params[:id])

    respond_to do |format|
      format.html # show.html.erb
      format.xml  { render :xml => @package }
    end
  end

  # GET /packages/new
  # GET /packages/new.xml
  def new
    @package = Package.new

    respond_to do |format|
      format.html # new.html.erb
      format.xml  { render :xml => @package }
    end
  end

  # GET /packages/1/edit
  def edit
    @package = Package.find(params[:id])
  end

  # POST /packages
  # POST /packages.xml
  def create
#    if params[:key]
#      if params[:package] && params[:user]
#        mp = MaintainersPackage.new()
#        mp.maintainer = Maintainer.find_or_create_by_email(params[:user])
#        mp.package = Package.find_or_create_by_name(params[:package])
#        mp.save
#        render :status => :created, :text => "created"
#      else
#        render :status => :bad_request, :text => "missing package or user parameters"
#      end
#    else
#      render :status => :forbidden, :text => "forbidden access"
#    end
    @package = Package.new(params[:package])

    respond_to do |format|
      if @package.save
        format.html { redirect_to(@package, :notice => 'Package was successfully created.') }
        format.xml  { render :xml => @package, :status => :created, :location => @package }
      else
        format.html { render :action => "new" }
        format.xml  { render :xml => @package.errors, :status => :unprocessable_entity }
      end
    end
  end

  # PUT /packages/1
  # PUT /packages/1.xml
  def update
    @package = Package.find(params[:id])

    respond_to do |format|
      if @package.update_attributes(params[:package])
        format.html { redirect_to(@package, :notice => 'Package was successfully updated.') }
        format.xml  { head :ok }
      else
        format.html { render :action => "edit" }
        format.xml  { render :xml => @package.errors, :status => :unprocessable_entity }
      end
    end
  end

  # DELETE /packages/1
  # DELETE /packages/1.xml
  def destroy
    @package = Package.find(params[:id])
    @package.destroy

    respond_to do |format|
      format.html { redirect_to(packages_url) }
      format.xml  { head :ok }
    end
  end
end
